@@ -3,3 +3,5 @@ from .datamodel import Datamodel
 from .permission import Permission
 from .hierarchy import Hierarchy
 from .datasecurity import DataSecurity
+from .connection import Connection
+from .elasticube import Elasticube
